@@ -50,10 +50,10 @@
 #include <QStringList>
 #include <QStringMatcher>
 #include <QRegularExpression>
+#include <QUrl>
 
 #include "qzcommon.h"
 
-class QUrl;
 class QWebEngineUrlRequestInfo;
 
 class AdBlockSubscription;
@@ -74,6 +74,7 @@ public:
     QString filter() const;
     void setFilter(const QString &filter);
 
+    bool isRemoveRule() const;
     bool isCssRule() const;
     QString cssSelector() const;
 
@@ -90,6 +91,9 @@ public:
     bool isEnabled() const;
     void setEnabled(bool enabled);
 
+    bool isRewrite() const;
+    QUrl rewriteUrl() const;
+
     bool isSlow() const;
     bool isInternalDisabled() const;
 
@@ -117,7 +121,8 @@ private:
         MatchAllUrlsRule = 5,
         ExtendedCssRule = 6,
         SnippetRule = 7,
-        Invalid = 8
+        RemoveRule = 8,
+        Invalid = 9
     };
 
     enum RuleOption {
@@ -135,7 +140,8 @@ private:
         PingOption              = 1 << 9,
         MediaOption             = 1 << 10,
         FontOption              = 1 << 11,
-        OtherOption             = 1 << 12,
+        WebSocketOption         = 1 << 12,
+        OtherOption             = 1 << 13,
         TypeOptions = ObjectOption
                     | SubdocumentOption
                     | XMLHttpRequestOption
@@ -146,9 +152,11 @@ private:
                     | PingOption
                     | MediaOption
                     | FontOption
+                    | WebSocketOption
                     | OtherOption,
 
-        PopupOption             = 1 << 13,
+        PopupOption             = 1 << 14,
+        RewriteOption           = 1 << 15,
 
         // Exception only options
         DocumentOption          = 1 << 20,
@@ -166,6 +174,7 @@ private:
     inline void setException(const RuleOption &opt, bool on);
 
     void parseFilter();
+    bool parseRewriteFilter(const QString &filter);
     void parseDomains(const QString &domains, const QChar &separator);
     bool filterIsOnlyDomain(const QString &filter) const;
     bool filterIsOnlyEndsMatch(const QString &filter) const;
@@ -184,6 +193,7 @@ private:
     QString m_matchString;
     // Case sensitivity for string matching
     Qt::CaseSensitivity m_caseSensitivity;
+    QUrl m_rewriteTarget;
 
     bool m_isEnabled;
     bool m_isException;
